@@ -9,10 +9,10 @@ import hypothesis
 
 from ..._hypothesis import make_test_or_exception
 from ...models import CheckFunction, TestResultSet
-from ...schemas import BaseSchema
 from ...types import RawAuth
 from ...utils import capture_hypothesis_output, get_requests_auth
 from .. import events
+from ..targeted import Target
 from .core import BaseRunner, get_session, network_test, run_test, wsgi_test
 
 
@@ -20,8 +20,8 @@ def _run_task(
     test_template: Callable,
     tasks_queue: Queue,
     events_queue: Queue,
-    schema: BaseSchema,
     checks: Iterable[CheckFunction],
+    targets: Iterable[Target],
     settings: hypothesis.settings,
     seed: Optional[int],
     results: TestResultSet,
@@ -32,15 +32,15 @@ def _run_task(
         while not tasks_queue.empty():
             endpoint = tasks_queue.get()
             test = make_test_or_exception(endpoint, test_template, settings, seed)
-            for event in run_test(schema, endpoint, test, checks, results, **kwargs):
+            for event in run_test(endpoint, test, checks, targets, results, **kwargs):
                 events_queue.put(event)
 
 
 def thread_task(
     tasks_queue: Queue,
     events_queue: Queue,
-    schema: BaseSchema,
     checks: Iterable[CheckFunction],
+    targets: Iterable[Target],
     settings: hypothesis.settings,
     auth: Optional[RawAuth],
     auth_type: Optional[str],
@@ -55,24 +55,34 @@ def thread_task(
     """
     # pylint: disable=too-many-arguments
     prepared_auth = get_requests_auth(auth, auth_type)
-    with get_session(prepared_auth, headers) as session:
+    with get_session(prepared_auth) as session:
         _run_task(
-            network_test, tasks_queue, events_queue, schema, checks, settings, seed, results, session=session, **kwargs
+            network_test,
+            tasks_queue,
+            events_queue,
+            checks,
+            targets,
+            settings,
+            seed,
+            results,
+            session=session,
+            headers=headers,
+            **kwargs,
         )
 
 
 def wsgi_thread_task(
     tasks_queue: Queue,
     events_queue: Queue,
-    schema: BaseSchema,
     checks: Iterable[CheckFunction],
+    targets: Iterable[Target],
     settings: hypothesis.settings,
     seed: Optional[int],
     results: TestResultSet,
     kwargs: Any,
 ) -> None:
     # pylint: disable=too-many-arguments
-    _run_task(wsgi_test, tasks_queue, events_queue, schema, checks, settings, seed, results, **kwargs)
+    _run_task(wsgi_test, tasks_queue, events_queue, checks, targets, settings, seed, results, **kwargs)
 
 
 def stop_worker(thread_id: int) -> None:
@@ -147,15 +157,15 @@ class ThreadPoolRunner(BaseRunner):
         return {
             "tasks_queue": tasks_queue,
             "events_queue": events_queue,
-            "schema": self.schema,
             "checks": self.checks,
+            "targets": self.targets,
             "settings": self.hypothesis_settings,
             "auth": self.auth,
             "auth_type": self.auth_type,
             "headers": self.headers,
             "seed": self.seed,
             "results": results,
-            "kwargs": {"request_timeout": self.request_timeout},
+            "kwargs": {"request_timeout": self.request_timeout, "store_interactions": self.store_interactions},
         }
 
 
@@ -167,12 +177,17 @@ class ThreadPoolWSGIRunner(ThreadPoolRunner):
         return {
             "tasks_queue": tasks_queue,
             "events_queue": events_queue,
-            "schema": self.schema,
             "checks": self.checks,
+            "targets": self.targets,
             "settings": self.hypothesis_settings,
             "seed": self.seed,
             "results": results,
-            "kwargs": {"auth": self.auth, "auth_type": self.auth_type, "headers": self.headers},
+            "kwargs": {
+                "auth": self.auth,
+                "auth_type": self.auth_type,
+                "headers": self.headers,
+                "store_interactions": self.store_interactions,
+            },
         }
 
 
