@@ -3,8 +3,10 @@ import pathlib
 import re
 import sys
 import traceback
+import warnings
 from contextlib import contextmanager
-from typing import Any, Callable, Dict, Generator, List, Optional, Set, Tuple, Type, Union
+from functools import wraps
+from typing import Any, Callable, Dict, Generator, List, Optional, Set, Tuple, Type, Union, overload
 from urllib.parse import urlsplit, urlunsplit
 
 import requests
@@ -18,9 +20,30 @@ from werkzeug.wrappers.json import JSONMixin
 
 from .types import Filter, NotSet, RawAuth
 
+try:
+    from yaml import CSafeLoader as SafeLoader
+except ImportError:
+    # pylint: disable=unused-import
+    from yaml import SafeLoader  # type: ignore
+
+
 NOT_SET = NotSet()
 
 
+def deprecated(message: str) -> Callable:
+    """Emit a warning if the given function is used."""
+
+    def wrapper(func: Callable) -> Callable:
+        @wraps(func)  # pragma: no mutate
+        def inner(*args: Any, **kwargs: Any) -> Any:
+            warnings.warn(message, DeprecationWarning)
+            return func(*args, **kwargs)
+
+        return inner
+
+    return wrapper
+
+
 def file_exists(path: str) -> bool:
     try:
         return pathlib.Path(path).is_file()
@@ -141,7 +164,7 @@ def are_content_types_equal(source: str, target: str) -> bool:
 
 def make_loader(*tags_to_remove: str) -> Type[yaml.SafeLoader]:
     """Create a YAML loader, that doesn't parse specific tokens into Python objects."""
-    cls: Type[yaml.SafeLoader] = type("YAMLLoader", (yaml.SafeLoader,), {})
+    cls: Type[yaml.SafeLoader] = type("YAMLLoader", (SafeLoader,), {})
     cls.yaml_implicit_resolvers = {
         key: [(tag, regexp) for tag, regexp in mapping if tag not in tags_to_remove]
         for key, mapping in cls.yaml_implicit_resolvers.copy().items()
@@ -173,3 +196,38 @@ def import_app(path: str) -> Any:
     # may return a parent module (system dependent)
     module = sys.modules[path]
     return getattr(module, name)
+
+
+Schema = Union[Dict[str, Any], List, str, float, int]
+
+
+@overload
+def traverse_schema(schema: Dict[str, Any], callback: Callable, *args: Any, **kwargs: Any) -> Dict[str, Any]:
+    pass
+
+
+@overload
+def traverse_schema(schema: List, callback: Callable, *args: Any, **kwargs: Any) -> List:
+    pass
+
+
+@overload
+def traverse_schema(schema: str, callback: Callable, *args: Any, **kwargs: Any) -> str:
+    pass
+
+
+@overload
+def traverse_schema(schema: float, callback: Callable, *args: Any, **kwargs: Any) -> float:
+    pass
+
+
+def traverse_schema(schema: Schema, callback: Callable[..., Dict[str, Any]], *args: Any, **kwargs: Any) -> Schema:
+    """Apply callback recursively to the given schema."""
+    if isinstance(schema, dict):
+        schema = callback(schema, *args, **kwargs)
+        for key, sub_item in schema.items():
+            schema[key] = traverse_schema(sub_item, callback, *args, **kwargs)
+    elif isinstance(schema, list):
+        for idx, sub_item in enumerate(schema):
+            schema[idx] = traverse_schema(sub_item, callback, *args, **kwargs)
+    return schema
